Documentation
¶
Index ¶
- Constants
- func ListProcessFilePaths() (paths []fs.DirEntry, err error)
- func ProcessedItemToString(p ProcessedItem) string
- type AddrData
- type AddrResponse
- type Model
- func (m Model) GetSelectedItem() ProcessedItem
- func (m Model) GetTotalItems() int
- func (m Model) Init() tea.Cmd
- func (m Model) ListenForProcessedItem() tea.Cmd
- func (m *Model) NewStatusMessageCmd(s string) tea.Cmd
- func (m *Model) SetDebugging(debugging bool)
- func (m *Model) SetDisabled(disabled bool)
- func (m *Model) SetSize(width, height int)
- func (m Model) Update(msg tea.Msg) (Model, tea.Cmd)
- func (m Model) View() string
- type ProcessedItem
Constants ¶
const ( IdleState processingState = iota ProcessingState )
const ADDRESS_DATA_DIRECTORY = "./__input/addr-data"
const DURATION_MINUTE_DELAY_THRESHOLD = 10.0
const DURATION_MINUTE_DELAY_THRESHOLD = 10
const MINIMUM_DURATION_LOGGING_THRESHOLD = 0.1
In minutes
const MINIMUM_PROCESSING_COUNT_LOGGING_THRESHOLD = 2
Minimum number on records which consider a valid item
const MINIMUM_SPEED_LOGGING_THRESHOLD = 0.0001
In miles
const OUTPUT_DATA_FILE = "./__output/"
Variables ¶
This section is empty.
Functions ¶
func ListProcessFilePaths ¶
func ProcessedItemToString ¶
func ProcessedItemToString(p ProcessedItem) string
Types ¶
type AddrData ¶
type AddrData struct {
//** Ip Address of RSU */
Ip string `json:"ip"`
//** Longitude */
Lng float64 `json:"lon"`
//** Latitude */
Lat float64 `json:"lat"`
//** Mac address */
Addr string `json:"addr"`
Flags int `json:"flags"`
//** Strength of signal */
Rssi int `json:"rssi"`
//** Distance from RSU */
Seen int `json:"seen"`
//** Timestamp of entry */
Time string `json:"time"`
//** Capture of entry (e.g., 'wifi', 'bluetooth', etc.) */
CaptureType string `json:"type"`
}
type AddrResponse ¶
type AddrResponse []AddrData
type Model ¶
type Model struct {
Cursor int
Disabled bool
StatusMessage string
StatusMessageLifetime time.Duration
State processingState
// contains filtered or unexported fields
}
func (Model) GetSelectedItem ¶
func (m Model) GetSelectedItem() ProcessedItem
GetSelectedItem returns the currently selected file/dir.
func (Model) GetTotalItems ¶
GetTotalItems returns total number of tree items.
func (Model) ListenForProcessedItem ¶
func (*Model) NewStatusMessageCmd ¶
NewStatusMessageCmd sets a new status message, which will show for a limited amount of time. Note that this also returns a command.
func (*Model) SetDebugging ¶
func (*Model) SetDisabled ¶
SetDisabled sets if the bubble is currently active.
type ProcessedItem ¶
func ProcessFilePath ¶
func ProcessFilePath(file fs.DirEntry) (item []ProcessedItem, err error)
Click to show internal directories.
Click to hide internal directories.